/*
 *   Copyright 2013 Brian Rosenberger (Brutex Network)
 *
 *   Licensed under the Apache License, Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 */

package net.brutex.xservices.types.ant;

import java.util.Date;
import java.util.GregorianCalendar;
import java.util.TimeZone;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import net.brutex.xservices.types.DateFormatType;

/**
 * @author Brian Rosenberger, bru(at)brutex.de
 *
 */
@XmlType(name="DateInfoType", namespace="http://ws.xservices.brutex.net", propOrder={"isoDate", "rfcDate", "millis"})
public class DateInfoType
{
  public static final String XML_NAME = "DateInfoType";
  private final GregorianCalendar date;
  private final TimeZone zone;

  public DateInfoType(GregorianCalendar date, TimeZone zone)
  {
    this.date = date;
    this.zone = zone;
  }

  public DateInfoType()
  {
    this.zone = TimeZone.getDefault();
    this.date = new GregorianCalendar(this.zone);
  }

  @XmlElement(name="timestamp")
  public long getMillis()
  {
    return this.date.getTimeInMillis();
  }

  @XmlElement(name="iso8601date")
  public Date getIsoDate()
  {
    return this.date.getTime();
  }

  @XmlElement(name="rfc822date")
  public String getRfcDate()
  {
    return DateFormatType.RFC822.format(this.date.getTime(), null, null);
  }
}
